using System;
using Server.Gumps;
using Server.Network;
using Server.Items;

namespace Server.Engines.Craft
{
	public class CraftGumpItem : Gump
	{
		private Mobile m_From;
		private CraftSystem m_CraftSystem;
		private CraftItem m_CraftItem;
		private int m_SelectedGroup;
		private int m_ResIndex;
		private BaseTool m_Tool;

		private const int LabelHue = 0x480; // 0x384
		private const int LabelColor = 0x7FFF;

		public CraftGumpItem( Mobile from, CraftSystem craftSystem, CraftItem craftItem, int selectedGroup, int resIndex, BaseTool tool ) : base( 40, 40 )
		{
			m_From = from;
			m_CraftSystem = craftSystem;
			m_CraftItem = craftItem;
			m_SelectedGroup = selectedGroup;
			m_ResIndex = resIndex;
			m_Tool = tool;

			from.CloseGump( typeof( CraftGump ) );
			from.CloseGump( typeof( CraftGumpItem ) );

			AddPage( 0 );
			AddBackground( 0, 0, 530, 417, 5054 );
			AddImageTiled( 10, 10, 510, 22, 2624 );
			AddImageTiled( 10, 37, 150, 148, 2624 );
			AddImageTiled( 165, 37, 355, 90, 2624 );
			AddImageTiled( 10, 190, 155, 22, 2624 );
			AddImageTiled( 10, 217, 150, 53, 2624 );
			AddImageTiled( 165, 132, 355, 80, 2624 );
			AddImageTiled( 10, 275, 155, 22, 2624 );
			AddImageTiled( 10, 302, 150, 53, 2624 );
			AddImageTiled( 165, 217, 355, 80, 2624 );
			AddImageTiled( 10, 360, 155, 22, 2624 );
			AddImageTiled( 165, 302, 355, 80, 2624 );
			AddImageTiled( 10, 387, 510, 22, 2624 );
			AddAlphaRegion( 10, 10, 510, 397 );

			AddHtmlLocalized( 170, 40, 150, 20, 1044053, LabelColor, false, false ); // ITEM
			AddHtmlLocalized( 10, 192, 150, 22, 1044054, LabelColor, false, false ); // <CENTER>SKILLS</CENTER>
			AddHtmlLocalized( 10, 277, 150, 22, 1044055, LabelColor, false, false ); // <CENTER>MATERIALS</CENTER>
			AddHtmlLocalized( 10, 362, 150, 22, 1044056, LabelColor, false, false ); // <CENTER>OTHER</CENTER>

			if ( craftSystem.GumpTitleNumber > 0 )
				AddHtmlLocalized( 10, 12, 510, 20, craftSystem.GumpTitleNumber, LabelColor, false, false );
			else
				AddHtml( 10, 12, 510, 20, craftSystem.GumpTitleString, false, false );

			AddButton( 15, 387, 4014, 4016, 0, GumpButtonType.Reply, 0 );
			AddHtmlLocalized( 50, 390, 150, 18, 1044150, LabelColor, false, false ); // BACK

			AddButton( 270, 387, 4005, 4007, 1, GumpButtonType.Reply, 0 );
			AddHtmlLocalized( 305, 390, 150, 18, 1044151, LabelColor, false, false ); // MAKE NOW

			if ( craftItem.NameNumber > 0 )
				AddHtmlLocalized( 330, 40, 180, 18, craftItem.NameNumber, LabelColor, false, false );
			else
				AddLabel( 330, 40, LabelHue, craftItem.NameString );

			if ( craftItem.UseAllRes )
				AddHtmlLocalized( 170, 302, 310, 18, 1048176, LabelColor, false, false ); // Makes as many as possible at once

			DrawItem();
			DrawSkill();
			DrawRessource();
		}

		public void DrawItem()
		{
			Item item = Activator.CreateInstance( m_CraftItem.ItemType ) as Item;

			if ( item != null )
			{
				AddItem( 20, 50, item.ItemID );

				item.Delete();
			}
		}

		public void DrawSkill()
		{
			double minMainSkill = 0.0, maxMainSkill = 0.0, valMainSkill = 0.0;
			bool allRequiredSkills = true;

			for ( int i = 0; i < m_CraftItem.Skills.Count; i++ )
			{
				CraftSkill skill = m_CraftItem.Skills.GetAt( i );
				double minSkill = skill.MinSkill, maxSkill = skill.MaxSkill;

				if ( m_CraftItem.Skills.GetAt(i).SkillToMake == m_CraftSystem.MainSkill )
				{
					Type type = null;

					if ( m_ResIndex > -1 )
					{
						type = m_CraftSystem.CraftSubRes.GetAt( m_ResIndex ).ItemType;
						CraftItem.AdjustSkillsValue( m_From, type, m_CraftSystem, ref minSkill, ref maxSkill );
					}
				}

				double skillValue = m_From.Skills[skill.SkillToMake].Value;

				if ( skillValue < minSkill )
					allRequiredSkills = false;

				if ( skill.SkillToMake == m_CraftSystem.MainSkill )
				{
					minMainSkill = minSkill;
					maxMainSkill = maxSkill;
					valMainSkill = skillValue;
				}

				AddHtmlLocalized( 170, 132 + (i * 20), 200, 18, 1044060 + (int)skill.SkillToMake, LabelColor, false, false );
				AddLabel( 430, 132 + (i * 20), LabelHue, String.Format( "{0:F1}", minSkill ) );
			}

			double chance;

			if ( allRequiredSkills )
				chance = 0.5 + ((valMainSkill - minMainSkill) / (maxMainSkill - minMainSkill) / 2);
			else
				chance = 0.0;

			if ( allRequiredSkills && valMainSkill == maxMainSkill )
				chance = 1.0;

			double excepChance = m_CraftItem.GetExceptionalChance( chance );

			if ( chance < 0.0 )
				chance = 0.0;
			else if ( chance > 1.0 )
				chance = 1.0;

			if ( excepChance < 0.0 )
				excepChance = 0.0;
			else if ( excepChance > 1.0 )
				excepChance = 1.0;

			AddHtmlLocalized( 170, 80, 250, 18, 1044057, LabelColor, false, false ); // Success Chance:
			AddLabel( 430, 80, LabelHue, String.Format( "{0:F1}%", chance * 100 ) );

			AddHtmlLocalized( 170, 100, 250, 18, 1044058, 32767, false, false ); // Exceptional Chance:
			AddLabel( 430, 100, LabelHue, String.Format( "{0:F1}%", excepChance * 100 ) );
		}

		public void DrawRessource()
		{
			for ( int i = 0; i < m_CraftItem.Ressources.Count && i < 4; i++ )
			{
				Type type;
				string nameString;
				int nameNumber;

				CraftRes craftResource = m_CraftItem.Ressources.GetAt( i );

				type = craftResource.ItemType;
				nameString = craftResource.NameString;
				nameNumber = craftResource.NameNumber;
				
				// Resource Mutation
				if ( type == m_CraftSystem.CraftSubRes.ResType && m_ResIndex > -1 )
				{
					CraftSubRes subResource = m_CraftSystem.CraftSubRes.GetAt( m_ResIndex );

					nameString = subResource.NameString;
					nameNumber = subResource.GenericNameNumber;

					if ( nameNumber <= 0 )
						nameNumber = subResource.NameNumber;
				}
				// ******************

				if ( nameNumber > 0 )
					AddHtmlLocalized( 170, 219 + (i * 20), 310, 18, nameNumber, LabelColor, false, false );
				else
					AddLabel( 170, 219 + (i * 20), LabelHue, nameString );

				AddLabel( 430, 219 + (i * 20), LabelHue, craftResource.Amount.ToString() );
			}

			if ( m_CraftItem.NameNumber == 1041267 ) // runebook
			{
				AddHtmlLocalized( 170, 219 + (m_CraftItem.Ressources.Count * 20), 310, 18, 1044447, LabelColor, false, false );
				AddLabel( 430, 219 + (m_CraftItem.Ressources.Count * 20), LabelHue, "1" );
			}

		}

		public override void OnResponse( NetState sender, RelayInfo info )
		{
			// Back Button
			if ( info.ButtonID == 0 )
			{
				CraftGump craftGump = new CraftGump( m_From, m_CraftSystem, m_SelectedGroup, m_ResIndex, m_Tool, null );
				m_From.SendGump( craftGump );
			}
			else // Make Button
			{
				int num = m_CraftSystem.CanCraft( m_From, m_Tool, m_CraftItem.ItemType );

				if ( num > 0 )
				{
					m_From.SendGump( new CraftGump( m_From, m_CraftSystem, m_SelectedGroup, m_ResIndex, m_Tool, num ) );
				}
				else
				{
					Type type = null;
					if ( m_ResIndex > -1 )
					{
						type = m_CraftSystem.CraftSubRes.GetAt( m_ResIndex ).ItemType;
					}
					m_CraftSystem.CreateItem( m_From, m_CraftItem.ItemType, type, m_Tool, m_CraftItem, m_SelectedGroup, m_ResIndex );
				}
			}
		}
	}
}