using System;
using Server.Items;

namespace Server.Engines.Craft
{
	public enum ConsumeType
	{
		All, Half, None
	}

	public class CraftItem
	{
		private CraftResCol m_arCraftRes;
		private CraftSkillCol m_arCraftSkill;
		private Type m_Type;

		private string m_GroupNameString;
		private int m_GroupNameNumber;

		private string m_NameString;
		private int m_NameNumber;
		
		private int m_Mana;
		private int m_Hits;
		private int m_Stam;

		private bool m_UseAllRes = false;

		public CraftItem( Type type, string groupName, string name )
		{
			m_arCraftRes = new CraftResCol();
			m_arCraftSkill = new CraftSkillCol();

			m_Type = type;
			m_GroupNameString = groupName;
			m_NameString = name;
		}

		public CraftItem( Type type, int groupName, int name )
		{
			m_arCraftRes = new CraftResCol();
			m_arCraftSkill = new CraftSkillCol();

			m_Type = type;
			m_GroupNameNumber = groupName;
			m_NameNumber = name;
		}

		public CraftItem( Type type, int groupName, string name )
		{
			m_arCraftRes = new CraftResCol();
			m_arCraftSkill = new CraftSkillCol();

			m_Type = type;
			m_GroupNameNumber = groupName;
			m_NameString = name;
		}

		public void AddRes( Type type, int name, int amount )
		{
			AddRes( type, name, amount, "" );
		}

		public void AddRes( Type type, int name, int amount, int localizedMessage )
		{
			CraftRes craftRes = new CraftRes( type, name, amount, localizedMessage );
			m_arCraftRes.Add( craftRes );
		}

		public void AddRes( Type type, int name, int amount, string strMessage )
		{
			CraftRes craftRes = new CraftRes( type, name, amount, strMessage );
			m_arCraftRes.Add( craftRes );
		}

		public void AddRes( Type type, string name, int amount )
		{
			AddRes( type, name, amount, "" );
		}

		public void AddRes( Type type, string name, int amount, int localizedMessage )
		{
			CraftRes craftRes = new CraftRes( type, name, amount, localizedMessage );
			m_arCraftRes.Add( craftRes );
		}

		public void AddRes( Type type, string name, int amount, string strMessage )
		{
			CraftRes craftRes = new CraftRes( type, name, amount, strMessage );
			m_arCraftRes.Add( craftRes );
		}

		public void AddSkill( SkillName skillToMake, double minSkill, double maxSkill )
		{
			CraftSkill craftSkill = new CraftSkill( skillToMake, minSkill, maxSkill );
			m_arCraftSkill.Add( craftSkill );
		}

		public int Mana
		{
			get { return m_Mana; }
			set { m_Mana = value; }
		}

		public int Hits
		{
			get { return m_Hits; }
			set { m_Hits = value; }
		}

		public int Stam
		{
			get { return m_Stam; }
			set { m_Stam = value; }
		}

		public bool UseAllRes
		{
			get { return m_UseAllRes; }
			set { m_UseAllRes = value; }
		}
		
		public Type ItemType
		{
			get { return m_Type; }
		}

		public string GroupNameString
		{
			get { return m_GroupNameString; }
		}

		public int GroupNameNumber
		{
			get { return m_GroupNameNumber; }
		}

		public string NameString
		{
			get { return m_NameString; }
		}

		public int NameNumber
		{
			get { return m_NameNumber; }
		}

		public CraftResCol Ressources
		{
			get { return m_arCraftRes; }
		}

		public CraftSkillCol Skills
		{
			get { return m_arCraftSkill; }
		}

		public bool ConsumeAttributes( Mobile from, ref object message )
		{
			bool consumMana = false;
			bool consumHits = false;
			bool consumStam = false;
			
			if ( Hits > 0 && from.Hits < Hits )
			{
				message = "You lack the required hit points to make that.";
				return false;
			}
			else
			{
				consumHits = true;
			}

			if ( Mana > 0 && from.Mana < Mana )
			{
				message = "You lack the required mana to make that.";
				return false;
			}
			else
			{
				consumMana = true;
			}
			
			if ( Stam > 0 && from.Stam < Stam )
			{
				message = "You lack the required stamina to make that.";
				return false;
			}
			else
			{
				consumStam = true;
			}

			if ( consumMana )
				from.Mana -= Mana;

			if ( consumHits )
				from.Hits -= Hits;

			if ( consumStam )
				from.Stam -= Stam;

			return true;
		}

		private static Type[][] m_TypesTable = new Type[][]
			{
				new Type[]{ typeof( Log ), typeof( Board ) },
				new Type[]{ typeof( Leather ), typeof( Hides ) },
				new Type[]{ typeof( SpinedLeather ), typeof( SpinedHides ) },
				new Type[]{ typeof( HornedLeather ), typeof( HornedHides ) },
				new Type[]{ typeof( BarbedLeather ), typeof( BarbedHides ) }
			};

		public bool ConsumeRes( Mobile from, Type typeRes, CraftSystem craftSystem, ref int resHue, ref int maxAmount, ConsumeType consumeType, ref object message )
		{
			Container ourPack = from.Backpack;

			if ( ourPack == null )
				return false;

			Type[][] types = new Type[m_arCraftRes.Count][];
			int[] amounts = new int[m_arCraftRes.Count];

			maxAmount = int.MaxValue;

			for ( int i = 0; i < types.Length; ++i )
			{
				CraftRes craftRes = m_arCraftRes.GetAt( i );
				Type baseType = craftRes.ItemType;

				// Get the color of the first resource in the list
				if ( i == 0 )
				{
					Item itemColor = ourPack.FindItemByType( baseType );

					if ( itemColor != null )
					{
						if ( craftRes.Amount <= itemColor.Amount )
							resHue = itemColor.Hue;
					}
				}
				// ********

				// Resource Mutation
				if ( (baseType == craftSystem.CraftSubRes.ResType ) && ( typeRes != null ) )
					baseType = typeRes;
				// ******************

				for ( int j = 0; types[i] == null && j < m_TypesTable.Length; ++j )
				{
					if ( m_TypesTable[j][0] == baseType )
						types[i] = m_TypesTable[j];
				}

				if ( types[i] == null )
					types[i] = new Type[]{ baseType };

				amounts[i] = craftRes.Amount;

				// For stackable items that can ben crafted more than one at a time
				if ( UseAllRes )
				{
					int tempAmount = ourPack.GetAmount( types[i] );
					tempAmount /= amounts[i];
					if ( tempAmount < maxAmount )
					{
						maxAmount = tempAmount;

						if ( maxAmount == 0 )
						{
							CraftRes res = m_arCraftRes.GetAt( i );

							if ( res.MessageNumber > 0 )
								message = res.MessageNumber;
							else if ( res.MessageString != null && res.MessageString != String.Empty )
								message = res.NameString;
							else
								message = 502925; // You don't have the resources required to make that item.

							return false;
						}
					}
				}
				// ****************************
			}

			// We adjust the amount of each resource to consume the max posible
			if ( UseAllRes )
			{
				for ( int i = 0; i < amounts.Length; ++i )
					amounts[i] *= maxAmount;
			}
			else
				maxAmount = -1;

			Item consumeExtra = null;

			if ( m_NameNumber == 1041267 )
			{
				// Runebooks are a special case, they need a blank recall rune

				Item[] runes = ourPack.FindItemsByType( typeof( RecallRune ) );

				for ( int i = 0; i < runes.Length; ++i )
				{
					RecallRune rune = runes[i] as RecallRune;

					if ( rune != null && !rune.Marked )
					{
						consumeExtra = rune;
						break;
					}
				}

				if ( consumeExtra == null )
				{
					message = 1044253; // You don't have the components needed to make that.
					return false;
				}
			}
			
			int index = 0;

			// Consume ALL
			if ( consumeType == ConsumeType.All )
			{
				index = ourPack.ConsumeTotal( types, amounts, true );
			}

			// Consume Half ( for use all resource craft type )
			else if ( consumeType == ConsumeType.Half )
			{
				for ( int i = 0; i < amounts.Length; i++ )
					amounts[i] /= 2;

				index = ourPack.ConsumeTotal( types, amounts, true );
			}

			else // ConstumeType.None ( it's basicaly used to know if the crafter has enough resource before starting the process )
			{
				index = -1;
				for ( int i = 0; i < types.Length; i++ )
				{
					if ( ourPack.GetAmount( types[i], true ) < amounts[i] )
					{
						index = i;
						break;
					}
				}
			}

			if ( index == -1 )
			{
				if ( consumeType != ConsumeType.None )
					if ( consumeExtra != null )
						consumeExtra.Delete();

				return true;
			}
			else
			{
				CraftRes res = m_arCraftRes.GetAt( index );

				if ( res.MessageNumber > 0 )
					message = res.MessageNumber;
				else if ( res.MessageString != null && res.MessageString != String.Empty )
					message = res.NameString;
				else
					message = 502925; // You don't have the resources required to make that item.

				return false;
			}
		}

		public double GetExceptionalChance( double chance )
		{
			// There seem to be two algorithms
			// 1) (50% of chance) - 10%
			// 2) (100% of chance) - 60%

			return chance - 0.6;
		}

		public bool CheckSkills( Mobile from, Type typeRes, CraftSystem craftSystem, ref int quality, ref bool allRequiredSkills )
		{
			double chance = GetSuccessChance( from, typeRes, craftSystem, true, ref allRequiredSkills );

			if ( GetExceptionalChance( chance ) >= Utility.RandomDouble() )
				quality = 2;

			return ( chance >= Utility.RandomDouble() );
		}

		public double GetSuccessChance( Mobile from, Type typeRes, CraftSystem craftSystem, bool gainSkills, ref bool allRequiredSkills )
		{
			double minMainSkill = 0.0;
			double maxMainSkill = 0.0;
			double valMainSkill = 0.0;

			allRequiredSkills = true;

			for (int i = 0;  i < m_arCraftSkill.Count; i++)
			{
				CraftSkill craftSkill = m_arCraftSkill.GetAt(i);

				double minSkill = craftSkill.MinSkill;
				double maxSkill = craftSkill.MaxSkill;
				double valSkill = from.Skills[craftSkill.SkillToMake].Value;

				if ( valSkill < minSkill )
					allRequiredSkills = false;

				if ( craftSkill.SkillToMake == craftSystem.MainSkill )
				{
					if ( typeRes != null )
						AdjustSkillsValue( from, typeRes, craftSystem, ref minSkill, ref maxSkill );

					minMainSkill = minSkill;
					maxMainSkill = maxSkill;
					valMainSkill = valSkill;
				}

				if ( gainSkills ) // This is a passive check. Success chance is entirely dependant on the main skill
					from.CheckSkill( craftSkill.SkillToMake, minSkill, maxSkill );
			}

			double chance;

			if ( allRequiredSkills )
				chance = 0.5 + ((valMainSkill - minMainSkill) / (maxMainSkill - minMainSkill) / 2);
			else
				chance = 0.0;

			if ( allRequiredSkills && valMainSkill == maxMainSkill )
				chance = 1.0;

			return chance;
		}

		// Depending of the level of the selected resource, ajust the MinSkill and the MaxSkill for the CheckSkill
		public static void AdjustSkillsValue( Mobile from, Type typeRes, CraftSystem craftSystem, ref double minSkill, ref double maxSkill )
		{
			CraftSubRes craftSubRes = craftSystem.CraftSubRes.SearchFor( typeRes );

			double level = craftSubRes.ItemLevel;

			double minSkillValue = minSkill;
			minSkillValue /= 4;
			double minSkillAdjusted = minSkillValue * craftSubRes.ItemLevel;
			minSkill += ( minSkillAdjusted - minSkillValue );

			double maxSkillValue = maxSkill;
			maxSkillValue /= 4;
			double maxSkillAdjusted = maxSkillValue * craftSubRes.ItemLevel;
			maxSkill += ( maxSkillAdjusted - maxSkillValue );

			if ( maxSkill > 100 )
				maxSkill = 100;

			if ( minSkill > 100 )
				minSkill = 100;
		}

		public void Craft( Mobile from, CraftSystem craftSystem, Type typeRes, BaseTool tool, int selectedGroup, int resIndex )
		{
			if ( from.BeginAction( typeof( CraftSystem ) ) )
			{
				bool allRequiredSkills = true;
				double chance = GetSuccessChance( from, typeRes, craftSystem, false, ref allRequiredSkills );

				if ( allRequiredSkills && chance > 0.0 )
				{
					int resHue = 0;
					int maxAmount = 0;
					object message = null;

					if ( ConsumeRes( from, typeRes, craftSystem, ref resHue, ref maxAmount, ConsumeType.None, ref message ) )
					{
						message = null;

						if ( ConsumeAttributes( from, ref message ) )
						{
							CraftContext context = craftSystem.GetContext( from );

							if ( context != null )
								context.OnMade( this );

							int iMin = craftSystem.MinCraftEffect;
							int iMax = ( craftSystem.MaxCraftEffect - iMin ) + 1;
							int iRandom = Utility.Random( iMax );
							iRandom += iMin + 1;
							new InternalTimer( from, craftSystem, this, typeRes, tool, iRandom, resHue, maxAmount, selectedGroup, resIndex ).Start();
						}
						else
						{
							from.EndAction( typeof( CraftSystem ) );
							from.SendGump( new CraftGump( from, craftSystem, selectedGroup, resIndex, tool, message ) );
						}
					}
					else
					{
						from.EndAction( typeof( CraftSystem ) );
						from.SendGump( new CraftGump( from, craftSystem, selectedGroup, resIndex, tool, message ) );
					}
				}
				else
				{
					from.EndAction( typeof( CraftSystem ) );
					from.SendGump( new CraftGump( from, craftSystem, selectedGroup, resIndex, tool, 1044153 ) ); // You don't have the required skills to attempt this item.
				}
			}
			else
			{
				from.SendLocalizedMessage( 500119 ); // You must wait to perform another action
			}
		}

		private class InternalTimer : Timer
		{
			private Mobile m_From;
			private int m_iCount;
			private int m_iCountMax;
			private CraftItem m_CraftItem;
			private CraftSystem m_CraftSystem;
			private Type m_TypeRes;
			private BaseTool m_Tool;
			private int m_Hue;
			private int m_MaxAmount;
			private int m_SelectedGroup;
			private int m_ResIndex;

			public InternalTimer( Mobile from, CraftSystem craftSystem, CraftItem craftItem, Type typeRes, BaseTool tool, int iCountMax, int hue, int maxAmount, int selectedGroup, int resIndex ) : base( TimeSpan.Zero, TimeSpan.FromSeconds( craftSystem.Delay ), iCountMax )
			{
				m_From = from;
				m_CraftItem = craftItem;
				m_iCount = 0;
				m_iCountMax = iCountMax;
				m_CraftSystem = craftSystem;
				m_TypeRes = typeRes;
				m_Tool = tool;
				m_Hue = hue;
				m_MaxAmount = maxAmount;
				m_SelectedGroup = selectedGroup;
				m_ResIndex = resIndex;
			}

			protected override void OnTick()
			{
				m_iCount++;

				if ( m_iCount < m_iCountMax )
				{
					m_CraftSystem.PlayCraftEffect( m_From );
				}
				else
				{
					m_From.EndAction( typeof( CraftSystem ) );

					bool toolBroken = false;

					int quality = 1;
					int endquality = 1;

					bool allRequiredSkills = true;

					if ( m_CraftItem.CheckSkills( m_From, m_TypeRes, m_CraftSystem, ref quality, ref allRequiredSkills ) )
					{
						// Resource
						ConsumeType consumeType = ( m_CraftItem.UseAllRes ? ConsumeType.Half : ConsumeType.All );
						int resHue = 0;
						int maxAmount = 0;

						object message = null;

						// Not enough resource to craft it
						if ( !m_CraftItem.ConsumeRes( m_From, m_TypeRes, m_CraftSystem, ref resHue, ref maxAmount, ConsumeType.All, ref message ) )
						{
							if ( m_Tool != null && !m_Tool.Deleted && m_Tool.Durability > 0 )
								m_From.SendGump( new CraftGump( m_From, m_CraftSystem, m_SelectedGroup, m_ResIndex, m_Tool, message ) );
							else if ( message is int && (int)message > 0 )
								m_From.SendLocalizedMessage( (int)message );
							else if ( message is string )
								m_From.SendMessage( (string)message );

							return;
						}

						m_Tool.Durability--;

						if ( m_Tool.Durability < 1 )
							toolBroken = true;

						if ( toolBroken )
							m_Tool.Delete();

						Item item = Activator.CreateInstance( m_CraftItem.ItemType ) as Item;

						bool makersMark = false;

						if ( item != null )
						{
							if ( item is BaseWeapon )
							{
								BaseWeapon weapon = ( BaseWeapon )item;
								weapon.Quality = (WeaponQuality)quality;
								endquality = quality;

								if ( makersMark = (quality == 2) )
									weapon.Crafter = m_From;

								weapon.Hue = m_Hue;
							}
							else if ( item is BaseArmor )
							{
								BaseArmor armor = ( BaseArmor )item;
								armor.Quality = (ArmorQuality)quality;
								endquality = quality;

								if ( makersMark = (quality == 2) )
									armor.Crafter = m_From;

								Type resourceType = m_TypeRes;

								if ( resourceType == null )
									resourceType = m_CraftItem.Ressources.GetAt( 0 ).ItemType;

								if ( resourceType != null )
								{
									Item itemRes = Activator.CreateInstance( resourceType ) as Item;

									CraftResource resource;

									if ( itemRes is BaseIngot )
										resource = ((BaseIngot)itemRes).Resource;
									else if ( itemRes is BaseLeather )
										resource = ((BaseLeather)itemRes).Resource;
									else if ( itemRes is BaseHides )
										resource = ((BaseHides)itemRes).Resource;
									else
										resource = CraftResource.None;

									armor.Resource = resource;
								}
							}
							else if ( item is LockableContainer )
							{
								if ( m_From.CheckSkill( SkillName.Tinkering, -5.0, 15.0 ) )
								{
									LockableContainer cont = (LockableContainer)item;

									m_From.SendLocalizedMessage( 500636 ); // Your tinker skill was sufficient to make the item lockable.

									Key key = new Key( KeyType.Copper, Key.RandomValue() );

									cont.KeyValue = key.KeyValue;
									cont.DropItem( key );

									int level = (int)(m_From.Skills[SkillName.Tinkering].Value / 10);

									if ( level < 0 )
										level = 0;
									else if ( level > 10 )
										level = 10;

									cont.RequiredSkill = level * 10;
									cont.LockLevel = (level - 1) * 10;
									cont.MaxLockLevel = (level + 3) * 10;

									if ( cont.LockLevel == 0 )
										cont.LockLevel = -1;
								}
								else
								{
									m_From.SendLocalizedMessage( 500637 ); // Your tinker skill was insufficient to make the item lockable.
								}
							}
							else if ( item is Runebook )
							{
								int charges = 5 + quality + (int)(m_From.Skills[SkillName.Inscribe].Value / 30);
								endquality = quality;

								if ( charges > 10 )
									charges = 10;

								((Runebook)item).MaxCharges = charges;
							}
							else if ( item.Hue == 0 )
							{
								item.Hue = m_Hue;
							}

							if ( m_MaxAmount > 0 )
								item.Amount = m_MaxAmount;

							// **********************************************

							m_From.AddToBackpack( item );
							m_From.PlaySound( 0x57 );
						}

						int num = m_CraftSystem.PlayEndingEffect( m_From, false, true, toolBroken, endquality, makersMark, m_CraftItem );

						if ( m_Tool != null && !m_Tool.Deleted && m_Tool.Durability > 0 )
							m_From.SendGump( new CraftGump( m_From, m_CraftSystem, m_SelectedGroup, m_ResIndex, m_Tool, num ) );
						else if ( num > 0 )
							m_From.SendLocalizedMessage( num );
					}
					else if ( !allRequiredSkills )
					{
						if ( m_Tool != null && !m_Tool.Deleted && m_Tool.Durability > 0 )
							m_From.SendGump( new CraftGump( m_From, m_CraftSystem, m_SelectedGroup, m_ResIndex, m_Tool, 1044153 ) );
						else
							m_From.SendLocalizedMessage( 1044153 ); // You don't have the required skills to attempt this item.
					}
					else
					{
						ConsumeType consumeType = ( m_CraftItem.UseAllRes ? ConsumeType.Half : ConsumeType.All );
						int resHue = 0;
						int maxAmount = 0;

						object message = null;

						// Not enough resource to craft it
						if ( !m_CraftItem.ConsumeRes( m_From, m_TypeRes, m_CraftSystem, ref resHue, ref maxAmount, consumeType, ref message ) )
						{
							if ( m_Tool != null && !m_Tool.Deleted && m_Tool.Durability > 0 )
								m_From.SendGump( new CraftGump( m_From, m_CraftSystem, m_SelectedGroup, m_ResIndex, m_Tool, message ) );
							else if ( message is int && (int)message > 0 )
								m_From.SendLocalizedMessage( (int)message );
							else if ( message is string )
								m_From.SendMessage( (string)message );

							return;
						}

						m_Tool.Durability--;

						if ( m_Tool.Durability < 1 )
							toolBroken = true;

						if ( toolBroken )
							m_Tool.Delete();

						// SkillCheck failed.
						int num = m_CraftSystem.PlayEndingEffect( m_From, true, true, toolBroken, endquality, false, m_CraftItem );

						if ( m_Tool != null && !m_Tool.Deleted && m_Tool.Durability > 0 )
							m_From.SendGump( new CraftGump( m_From, m_CraftSystem, m_SelectedGroup, m_ResIndex, m_Tool, num ) );
						else if ( num > 0 )
							m_From.SendLocalizedMessage( num );
					}
				}
			}
		}
	}
}