using System;
using System.Net;
using Server;
using Server.Accounting;
using Server.Network;
using Server.Targets;
using Server.Scripts.Gumps;

namespace Server.Gumps
{
	public class ClientGump : Gump
	{
		private NetState m_State;

		private void Resend( Mobile to, RelayInfo info )
		{
			TextRelay te = info.GetTextEntry( 0 );

			to.SendGump( new ClientGump( to, m_State, te == null ? "" : te.Text ) );
		}

		public override void OnResponse( NetState state, RelayInfo info )
		{
			if ( m_State == null )
				return;

			Mobile focus = m_State.Mobile;
			Mobile from = state.Mobile;

			if ( focus == null )
			{
				from.SendMessage( "That character is no longer online." );
				return;
			}
			else if ( focus.Deleted )
			{
				from.SendMessage( "That character no longer exists." );
				return;
			}
			else if ( from != focus && focus.Hidden && from.AccessLevel < focus.AccessLevel )
			{
				from.SendMessage( "That character is no longer visible." );
				return;
			}

			switch ( info.ButtonID )
			{
				case 1: // Tell
				{
					TextRelay text = info.GetTextEntry( 0 );

					if ( text != null )
					{
						focus.SendMessage( 0x482, "{0} tells you:", from.Name );
						focus.SendMessage( 0x482, text.Text );
					}

					from.SendGump( new ClientGump( from, m_State ) );

					break;
				}
				case 4: // Props
				{
					Resend( from, info );
					from.SendGump( new PropertiesGump( from, focus ) );

					break;
				}
				case 5: // Goto
				{
					if ( focus.Map == null || focus.Map == Map.Internal )
					{
						from.SendMessage( "That character is not in the world." );
					}
					else
					{
						from.Map = focus.Map;
						from.Location = focus.Location;
						Resend( from, info );
					}

					break;
				}
				case 6: // Get
				{
					if ( from.Map == null || from.Map == Map.Internal )
					{
						from.SendMessage( "You cannot bring that person here." );
					}
					else
					{
						focus.Map = from.Map;
						focus.Location = from.Location;
						Resend( from, info );
					}

					break;
				}
				case 7: // Move
				{
					from.Target = new MoveTarget( focus );
					Resend( from, info );

					break;
				}
				case 8: // Kick
				{
					if ( from.AccessLevel >= AccessLevel.GameMaster && from.AccessLevel > focus.AccessLevel )
					{
						focus.Say( "I've been kicked!" );

						m_State.Dispose();
					}

					break;
				}
				case 9: // Kill
				{
					if ( from.AccessLevel >= AccessLevel.GameMaster && from.AccessLevel > focus.AccessLevel )
						focus.Kill();

					Resend( from, info );

					break;
				}
				case 10: //Res
				{
					if ( from.AccessLevel >= AccessLevel.GameMaster && from.AccessLevel > focus.AccessLevel )
					{
						focus.PlaySound( 0x214 );
						focus.FixedEffect( 0x376A, 10, 16 );

						focus.Resurrect();
					}

					Resend( from, info );

					break;
				}
				case 11: //skills
				{
					Resend( from, info );

					if ( from.AccessLevel > focus.AccessLevel )
						from.SendGump( new SkillsGump( from, (Mobile)focus ) );

					break;
				}
			}
		}

		public ClientGump( Mobile from, NetState state ) : this( from, state, "" )
		{
		}

		public ClientGump( Mobile from, NetState state, string initialText ) : base( 30, 20 )
		{
			if ( state == null )
				return;

			m_State = state;

			AddPage( 0 );

			AddBackground( 0, 0, 300, 370, 5054 );
			AddBackground( 8, 8, 284, 354, 3000 );

			AddLabel( 12, 12, 0, "Client Info" );

			int line = 0;

			AddLabel( 12, 38 + (line++ * 22), 0, String.Format( "Address: {0}", state ) );
			AddLabel( 12, 38 + (line++ * 22), 0, String.Format( "Version: {0}; Flags: 0x{1:X}", state.Version == null ? "(null)" : state.Version.ToString(), state.Flags ) );

			Account a = state.Account as Account;
			Mobile m = state.Mobile;

			if ( from.AccessLevel >= AccessLevel.GameMaster && a != null )
			{
				AddLabel( 12, 38 + (line++ * 22), 0, String.Format( "Account: {0}", a.Username ) );
			}

			if ( m != null )
			{
				AddLabel( 12, 38 + (line++ * 22), 0, String.Format( "Mobile: {0} (0x{1:X})", m.Name, m.Serial.Value ) );
				AddLabel( 12, 38 + (line++ * 22), 0, String.Format( "Location: {0} [{1}]", m.Location, m.Map ) );

				AddButton( 12, 38 + (line * 22), 0xFAB, 0xFAD, 1, GumpButtonType.Reply, 0 );
				AddImageTiled( 47, 38 + (line * 22), 234, 22, 0x52 );
				AddImageTiled( 48, 38 + (line * 22) + 1, 232, 20, 0xBBC );
				AddTextEntry( 48, 38 + (line++ * 22) + 1, 232, 20, 0, 0, initialText );
			}

			/*if ( from.AccessLevel >= AccessLevel.Administrator && a != null && from != m )
			{
				AddButton( 12, 38 + (line * 22), 0xFA2, 0xFA4, 2, GumpButtonType.Reply, 0 );
				AddLabel( 48, 38 + (line++ * 22), 0, "Ban" );
			}*/

			/*if ( from.AccessLevel >= AccessLevel.Administrator && from != m )
			{
				AddButton( 12, 38 + (line * 22), 0xFA2, 0xFA4, 3, GumpButtonType.Reply, 0 );
				AddLabel( 48, 38 + (line++ * 22), 0, "Firewall" );
			}*/

			if ( m != null )
			{
				AddButton( 12, 38 + (line * 22), 0xFB7, 0xFB9, 4, GumpButtonType.Reply, 0 );
				AddLabel( 48, 38 + (line++ * 22), 0, "Props" );

				if ( from != m )
				{
					AddButton( 12, 38 + (line * 22), 0xFA5, 0xFA7, 5, GumpButtonType.Reply, 0 );
					AddLabel( 48, 38 + (line++ * 22), 0, "Goto" );

					AddButton( 12, 38 + (line * 22), 0xFAE, 0xFB0, 6, GumpButtonType.Reply, 0 );
					AddLabel( 48, 38 + (line++ * 22), 0, "Get" );
				}

				AddButton( 12, 38 + (line * 22), 0xFA8, 0xFAA, 7, GumpButtonType.Reply, 0 );
				AddLabel( 48, 38 + (line++ * 22), 0, "Move" );

				if ( from.AccessLevel >= AccessLevel.GameMaster && from.AccessLevel > m.AccessLevel )
				{
					AddButton( 12, 38 + (line * 22), 0xFA2, 0xFA4, 8, GumpButtonType.Reply, 0 );
					AddLabel( 48, 38 + (line++ * 22), 0, "Kick" );

					AddButton( 12, 38 + (line * 22), 0xFB7, 0xFB9, 9, GumpButtonType.Reply, 0 );
					AddLabel( 48, 38 + (line++ * 22), 0, "Kill" );

					AddButton( 12, 38 + (line * 22), 0xFB7, 0xFB9, 10, GumpButtonType.Reply, 0 );
					AddLabel( 48, 38 + (line++ * 22), 0, "Resurrect" );

					AddButton( 12, 38 + (line * 22), 0xFB7, 0xFB9, 11, GumpButtonType.Reply, 0 );
					AddLabel( 48, 38 + (line++ * 22), 0, "Player's Skills" );
				}
			}
		}
	}
}