using System;
using Server;

namespace Server.Items
{
	[Flipable( 0x104B, 0x104C )]
	public class Clock : Item
	{
		private static DateTime m_ServerStart;

		public static void Initialize()
		{
			m_ServerStart = DateTime.Now;
		}

		[Constructable]
		public Clock() : this( 0x104B )
		{
		}

		[Constructable]
		public Clock( int itemID ) : base( itemID )
		{
			Weight = 2.0;
		}

		public Clock( Serial serial ) : base( serial )
		{
		}

		private const double SecondsPerUOMinute = 5.0;

		public override void OnDoubleClick( Mobile from )
		{
			TimeSpan timeSpan = DateTime.Now - m_ServerStart;

			double earthSeconds = timeSpan.TotalSeconds;
			double uoMinutes = earthSeconds / SecondsPerUOMinute;
			double uoHours = uoMinutes / 60.0;

			uoHours += 12.0; // server starts at noon

			uoMinutes %= 60.0;
			uoHours %= 24.0;

			int generalNumber;

			// 00:00 AM - 00:59 AM : Witching hour
			// 01:00 AM - 03:59 AM : Middle of night
			// 04:00 AM - 07:59 AM : Early morning
			// 08:00 AM - 11:59 AM : Late morning
			// 12:00 PM - 12:59 PM : Noon
			// 01:00 PM - 03:59 PM : Afternoon
			// 04:00 PM - 07:59 PM : Early evening
			// 08:00 PM - 11:59 AM : Late at night

			if ( uoHours >= 20.0 )
				generalNumber = 1042957; // It's late at night
			else if ( uoHours >= 16.0 )
				generalNumber = 1042956; // It's early in the evening
			else if ( uoHours >= 13.0 )
				generalNumber = 1042955; // It's the afternoon
			else if ( uoHours >= 12.0 )
				generalNumber = 1042954; // It's around noon
			else if ( uoHours >= 08.0 )
				generalNumber = 1042953; // It's late in the morning
			else if ( uoHours >= 04.0 )
				generalNumber = 1042952; // It's early in the morning
			else if ( uoHours >= 01.0 )
				generalNumber = 1042951; // It's the middle of the night
			else
				generalNumber = 1042950; // 'Tis the witching hour. 12 Midnight.

			uoHours %= 12.0;

			if ( uoHours < 1.0 )
				uoHours = 12.0;

			SendLocalizedMessageTo( from, generalNumber );
			SendLocalizedMessageTo( from, 1042958, String.Format( "{0:F0}:{1:D2}", uoHours, (int)uoMinutes ) ); // ~1_TIME~ to be exact
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}
	}

	[Flipable( 0x104B, 0x104C )]
	public class ClockRight : Clock
	{
		[Constructable]
		public ClockRight() : base( 0x104B )
		{
		}

		public ClockRight( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}
	}

	[Flipable( 0x104B, 0x104C )]
	public class ClockLeft : Clock
	{
		[Constructable]
		public ClockLeft() : base( 0x104C )
		{
		}

		public ClockLeft( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}
	}
}