using System;
using Server;
using Server.Items;
using Server.GenerateRandomMagicItems;

namespace Server.Mobiles
{
	[CorpseName( "a toxic elemental corpse" )]
	public class ToxicElemental : BaseCreature
	{
		[Constructable]
		public ToxicElemental () : base( AIType.AI_Mage, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Name = "a toxic elemental";
			Body = 13;
			Hue = 0x4001;
			BaseSoundID = 263;

			SetStr( 126, 152 );
			SetDex( 166, 185 );
			SetInt( 102, 121 );
			SetSkill( SkillName.Wrestling, 66, 82 );
			SetSkill( SkillName.Tactics, 62, 78 );
			SetSkill( SkillName.MagicResist, 63, 74 );
			SetSkill( SkillName.Magery, 67, 78 );

			ControlSlots = 2;

			VirtualArmor = 40;
			SetFameLevel( 3 );
			SetKarmaLevel( 3 );
			
			Katana kat = new Katana();
			kat.Movable = false;
			kat.Crafter = this;
			kat.Quality = WeaponQuality.Exceptional;
			AddItem( kat );
			

			switch ( Utility.Random( 6 ))
			{
				case 0: PackItem( new AgilityPotion() ); break;
				case 1: PackItem( new LesserCurePotion() ); break;
				case 2: PackItem( new LesserHealPotion() ); break;
				case 3: PackItem( new LesserPoisonPotion() ); break;
				case 4: PackItem( new RefreshPotion() ); break;
				case 5: PackItem( new StrengthPotion() ); break;
			}

			PackGold( 200, 300 );
			PackItem( RandomScroll.CreateScroll( 1, 6 ) );
			PackItem( RandomScroll.CreateScroll( 1, 6 ) );

			// 30% chance to get magic armor, then about 15% chance to get magic weapon
			if ( 0.3 >= Utility.RandomDouble() ) 
			{
				if ( 0.75 >= Utility.RandomDouble() )
				{
					PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 1, 5 ));
				}
				PackItem( RandomMagicItem.RandomMagicArmor( (BaseArmor)RandomMagicItem.RandomArmor, 1, 5 ));
			}
		}

		public override Poison HitPoison{ get{ return Poison.Lethal; } }
		public override double HitPoisonChance{ get{ return 0.6; } }

		public ToxicElemental( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}