using System;
using Server;
using Server.Items;
using Server.GenerateRandomMagicItems;

namespace Server.Mobiles
{
	[CorpseName( "an ophidian corpse" )]
	[TypeAlias( "Server.Mobiles.OphidianShaman" )]
	public class OphidianMage : BaseCreature
	{
		private static string[] m_Names = new string[]
			{
				"an ophidian apprentice mage",
				"an ophidian shaman"
			};

		[Constructable]
		public OphidianMage() : base( AIType.AI_Mage, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Name = m_Names[Utility.Random( m_Names.Length )];
			Body = 85;
			BaseSoundID = 639;

			SetStr( 181, 205 );
			SetDex( 191, 215 );
			SetInt( 96, 120 );

			SetHits( 109, 123 );

			SetDamage( 5, 10 );

			SetSkill( SkillName.EvalInt, 85.1, 100.0 );
			SetSkill( SkillName.Magery, 85.1, 100.0 );
			SetSkill( SkillName.MagicResist, 75.0, 97.5 );
			SetSkill( SkillName.Tactics, 65.0, 87.5 );
			SetSkill( SkillName.Wrestling, 20.2, 60.0 );

			Fame = 4000;
			Karma = -4000;

			VirtualArmor = 30;

			PackGem();

			switch ( Utility.Random( 6 ))
			{
				case 0: PackItem( new AgilityPotion() ); break;
				case 1: PackItem( new LesserCurePotion() ); break;
				case 2: PackItem( new LesserHealPotion() ); break;
				case 3: PackItem( new LesserPoisonPotion() ); break;
				case 4: PackItem( new RefreshPotion() ); break;
				case 5: PackItem( new StrengthPotion() ); break;
			}

			PackItem( new Arrow( 10 ));
			PackGold( 50, 150 );

			// 30% chance to get magic armor, then about 15% chance to get magic weapon
			if ( 0.3 >= Utility.RandomDouble() ) 
			{
				if ( 0.75 >= Utility.RandomDouble() )
				{
					PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 1, 5 ));
				}
				PackItem( RandomMagicItem.RandomMagicArmor( (BaseArmor)RandomMagicItem.RandomArmor, 1, 5 ));
			}
		}

		public override int TreasureMapLevel{ get{ return 2; } }

		public OphidianMage( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}