using System;
using System.Collections;
using Server.Items;

namespace Server.Mobiles
{
	public class GenericBuyInfo : IBuyItemInfo
	{
		private Type m_Type;
		private string m_Name;
		private int m_Price;
		private int m_MaxAmount, m_Amount;
		private int m_ItemID;
		private int m_Hue;

		public GenericBuyInfo( Type type, int price, int amount, int itemID, int hue ) : this( null, type, price, amount, itemID, hue )
		{
		}

		public GenericBuyInfo( string name, Type type, int price, int amount, int itemID, int hue )
		{
			m_Type = type;
			m_Price = price;
			m_MaxAmount = m_Amount = amount;
			m_ItemID = itemID;
			m_Hue = hue;

			if ( name == null )
				m_Name = (1020000 + (itemID & 0x3FFF)).ToString();
			else
				m_Name = name;
		}

		//get a new instance of an object (we just bought it)
		public object GetObject()
		{
			return Activator.CreateInstance( m_Type );
			//return (Item)Activator.CreateInstance( m_Type );
		}

		public virtual int ControlSlots
		{
			get
			{
				return 0;
			}
		}

		//display price of the item
		public int Price
		{ 
			get
			{
				return m_Price;
			}
		}

		//display name of the item
		public string Name
		{
			get
			{
				return m_Name;
			}
		}

		//display hue
		public int Hue
		{
			get
			{
				return m_Hue;
			}
		}

		//display id
		public int ItemID
		{
			get
			{
				return m_ItemID;
			}
		}

		//amount in stock
		public int Amount
		{ 
			get
			{
				return m_Amount;
			}
			set
			{
				m_Amount = value;
				if ( m_Amount < 0 )
					m_Amount = 0;
			}
		}

		//max amount in stock
		public int MaxAmount
		{
			get
			{
				return m_MaxAmount;
			}
		}

		//Attempt to restock with item, (return true if restock sucessful)
		public bool Restock( Item item, int amount )
		{
			if ( item.GetType() == m_Type )
			{
				if ( item is BaseWeapon )
				{
					BaseWeapon weapon = (BaseWeapon)item;

					if ( weapon.Quality == WeaponQuality.Low || weapon.Quality == WeaponQuality.Exceptional || (int)weapon.DurabilityLevel > 0 || (int)weapon.DamageLevel > 0 )
						return false;
				}

				if ( item is BaseArmor )
				{
					BaseArmor armor = (BaseArmor)item;

					if ( armor.Quality == ArmorQuality.Low || armor.Quality == ArmorQuality.Exceptional || (int)armor.Durability > 0 || (int)armor.ProtectionLevel > 0 )
						return false;
				}

				m_Amount += amount;

				return true;
			}
			else
			{
				return false;
			}
		}

		public void OnRestock()
		{
			if ( m_Amount < m_MaxAmount )
				m_Amount = m_MaxAmount;
		}
	}
}