using System;
using System.Collections;
using Server;
using Server.Mobiles;
using Server.Spells;

namespace Server.Regions
{
	public class TrammelTown : Region
	{
		public static void Initialize()
		{
			Region.AddRegion( new TrammelTown( "Cove", typeof( WarriorGuard ) ) );
			Region.AddRegion( new TrammelTown( "Britain", typeof( WarriorGuard ) ) );
			
			// Not a City
			//Region.AddRegion( new TrammelTown( "Britain Graveyard", typeof( WarriorGuard ) ) );
			//Region.AddRegion( new TrammelTown( "Lord British's Castle", typeof( WarriorGuard ) ) );
			//Region.AddRegion( new TrammelTown( "Lord Blackthorne's Castle", typeof( WarriorGuard ) ) );
			
			Region.AddRegion( new TrammelTown( "Jhelom", typeof( WarriorGuard ) ) );
			Region.AddRegion( new TrammelTown( "Minoc", typeof( WarriorGuard ) ) );
			Region.AddRegion( new TrammelTown( "Haven", typeof( WarriorGuard ) ) );
			Region.AddRegion( new TrammelTown( "Trinsic", typeof( WarriorGuard ) ) );
			Region.AddRegion( new TrammelTown( "Vesper", typeof( WarriorGuard ) ) );
			Region.AddRegion( new TrammelTown( "Yew", typeof( WarriorGuard ) ) );
			Region.AddRegion( new TrammelTown( "Wind", typeof( WarriorGuard ) ) );
			Region.AddRegion( new TrammelTown( "Serpent's Hold", typeof( WarriorGuard ) ) );
			Region.AddRegion( new TrammelTown( "Skara Brae", typeof( WarriorGuard ) ) );
			Region.AddRegion( new TrammelTown( "Nujel'm", typeof( WarriorGuard ) ) );
			Region.AddRegion( new TrammelTown( "Moonglow", typeof( WarriorGuard ) ) );
			Region.AddRegion( new TrammelTown( "Magincia", typeof( WarriorGuard ) ) );
		}

		private Type m_GuardType;
		private static object[] m_GuardParams = new object[1];

		public TrammelTown( string name, Type guardType ) : base( "the town of", name, Map.Trammel )
		{
			m_GuardType = guardType;
		}

		public override bool OnBeginSpellCast( Mobile m, ISpell s )
		{
			if ( !s.OnCastInTown( this ) )
			{
				m.SendLocalizedMessage( 500946 ); // You cannot cast this in town!
				return false;
			}

			return base.OnBeginSpellCast( m, s );
		}

		public override bool AllowHousing( Mobile from, Point3D p )
		{
			return false;
		}

		public override void MakeGuard( Mobile focus )
		{
			IPooledEnumerable eable = Map.GetMobilesInRange( focus.Location, 8 );

			foreach ( Mobile m in eable )
			{
				if ( m is BaseGuard )
				{
					BaseGuard g = (BaseGuard)m;

					if ( g.Focus == null ) // idling
					{
						g.Focus = focus;
						eable.Free();
						return;
					}
				}
			}

			eable.Free();

			m_GuardParams[0] = focus;

			Activator.CreateInstance( m_GuardType, m_GuardParams );
		}

		public override void OnEnter( Mobile m )
		{
			//base.OnEnter( m ); // You have entered the town of {0}

			m.SendLocalizedMessage( 500112 ); // You are now under the protection of the town guards.

			if ( m.Kills >= 5 )
				CheckGuardCandidate( m );
		}

		public override void OnExit( Mobile m )
		{
			base.OnExit( m );

			m.SendLocalizedMessage( 500113 ); // You have left the protection of the town guards.
		}

		public override void OnSpeech( SpeechEventArgs args )
		{
			if ( args.Mobile.Alive && args.HasKeyword( 0x0007 ) ) // *guards*
				CallGuards( args.Mobile.Location );
		}

		public override void OnAggressed( Mobile aggressor, Mobile aggressed, bool criminal )
		{
			base.OnAggressed( aggressor, aggressed, criminal );

			if ( aggressor != aggressed && criminal )
				CheckGuardCandidate( aggressor );
		}

		public override void OnGotBenificialAction( Mobile helper, Mobile helped )
		{
			base.OnGotBenificialAction( helper, helped );

			int noto = Notoriety.Compute( helper, helped );

			if ( helper != helped && (noto == Notoriety.Criminal || noto == Notoriety.Murderer) )
				CheckGuardCandidate( helper );
		}

		public override void OnCriminalAction( Mobile m, bool message )
		{
			base.OnCriminalAction( m, message );

			CheckGuardCandidate( m );
		}

		private Hashtable m_GuardCandidates = new Hashtable();

		public void CheckGuardCandidate( Mobile m )
		{
			if ( IsGuardCandidate( m ) )
			{
				GuardTimer timer = (GuardTimer)m_GuardCandidates[m];

				if ( timer == null )
				{
					timer = new GuardTimer( m, m_GuardCandidates );
					timer.Start();

					m_GuardCandidates[m] = timer;
					m.SendLocalizedMessage( 502275 ); // Guards can now be called on you!

					Map map = m.Map;

					if ( map != null )
					{
						IPooledEnumerable eable = map.GetMobilesInRange( m.Location, 8 );

						Mobile fakeCall = null;
						double prio = 0.0;

						foreach ( Mobile v in eable )
						{
							if ( !v.Player && v.Body.IsHuman && v != m && !IsGuardCandidate( v ) )
							{
								double dist = m.GetDistanceToSqrt( v );

								if ( fakeCall == null || dist < prio )
								{
									fakeCall = v;
									prio = dist;
								}
							}
						}

						eable.Free();

						if ( fakeCall != null )
						{
							fakeCall.Say( Utility.RandomList( 1007037, 501603, 1013037, 1013038, 1013039, 1013041, 1013042, 1013043, 1013052 ) );
							MakeGuard( m );
							m_GuardCandidates.Remove( m );
							m.SendLocalizedMessage( 502276 ); // Guards can no longer be called on you.
						}
					}
				}
				else
				{
					timer.Stop();
					timer.Start();
				}
			}
		}

		public void CallGuards( Point3D p )
		{
			IPooledEnumerable eable = Map.GetMobilesInRange( p, 14 );

			foreach ( Mobile m in eable )
			{
				if ( IsGuardCandidate( m ) && ((m.Kills >= 5 && Mobiles.Contains( m )) || m_GuardCandidates.Contains( m )) )
				{
					MakeGuard( m );
					m_GuardCandidates.Remove( m );
					m.SendLocalizedMessage( 502276 ); // Guards can no longer be called on you.
					break;
				}
			}

			eable.Free();
		}

		public bool IsGuardCandidate( Mobile m )
		{
			if ( m is BaseGuard || !m.Alive || m.AccessLevel > AccessLevel.Player )
				return false;

			return m.Kills >= 5 || m.Criminal;
		}

		private class GuardTimer : Timer
		{
			private Mobile m_Mobile;
			private Hashtable m_Table;

			public GuardTimer( Mobile m, Hashtable table ) : base( TimeSpan.FromSeconds( 15.0 ) )
			{
				Priority = TimerPriority.TwoFiftyMS;

				m_Mobile = m;
				m_Table = table;
			}

			protected override void OnTick()
			{
				if ( m_Table.Contains( m_Mobile ) )
				{
					m_Table.Remove( m_Mobile );
					m_Mobile.SendLocalizedMessage( 502276 ); // Guards can no longer be called on you.
				}
			}
		}
	}
}