using System;
using Server;
using Server.Gumps;
using Server.Mobiles;
using Server.Targeting;

namespace Server.SkillHandlers
{
	public class AnimalLore
	{
		public static void Initialize()
		{
			SkillInfo.Table[(int)SkillName.AnimalLore].Callback = new SkillUseCallback( OnUse );
		}

		public static TimeSpan OnUse(Mobile m)
		{
			m.Target = new InternalTarget();

			m.SendLocalizedMessage( 500328 ); // What animal should I look at?

			return TimeSpan.FromSeconds( 1.0 );
		}

		private class InternalTarget : Target
		{
			public InternalTarget() : base( 8, false, TargetFlags.None )
			{
			}

			protected override void OnTarget( Mobile from, object targeted )
			{
				if ( !from.Alive )
				{
					from.SendLocalizedMessage( 500331 ); // The spirits of the dead are not the province of animal lore.
				}
				else if ( targeted is BaseCreature )
				{
					BaseCreature c = (BaseCreature)targeted;

					if ( c.Body.IsAnimal || c.Body.IsMonster || c.Body.IsSea )
					{
						if ( (!c.Controled || !c.Tamable) && from.Skills[SkillName.AnimalLore].Base < 100.0 )
						{
							from.SendLocalizedMessage( 1049674 ); // At your skill level, you can only lore tamed creatures.
						}
						else if ( !c.Tamable && from.Skills[SkillName.AnimalLore].Base < 110.0 )
						{
							from.SendLocalizedMessage( 1049675 ); // At your skill level, you can only lore tamed or tameable creatures.
						}
						else if ( !from.CheckTargetSkill( SkillName.AnimalLore, c, 0.0, 120.0 ) )
						{
							from.SendLocalizedMessage( 500334 ); // You can't think of anything you know offhand.
						}
						else
						{
							from.CloseGump( typeof( AnimalLoreGump ) );
							from.SendGump( new AnimalLoreGump( c ) );
						}
					}
					else
					{
						from.SendLocalizedMessage( 500329 ); // That's not an animal!
					}
				}
				else
				{
					from.SendLocalizedMessage( 500329 ); // That's not an animal!
				}
			}
		}
	}

	public class AnimalLoreGump : Gump
	{
		private static string FormatSkill( BaseCreature c, SkillName name )
		{
			Skill skill = c.Skills[name];

			if ( skill.Base < 10.0 )
				return "<div align=right>---</div>";

			return String.Format( "<div align=right>{0}</div>", skill.Base );
		}

		public AnimalLoreGump( BaseCreature c ) : base( 250, 50 )
		{
			AddPage( 0 );

			AddImage( 100, 100, 2080 );
			AddImage( 118, 137, 2081 );
			AddImage( 118, 207, 2081 );
			AddImage( 118, 277, 2081 );
			AddImage( 118, 347, 2083 );

			AddHtml( 147, 108, 210, 18, String.Format( "<center><i>{0}</i></center>", c.Name ), false, false );

			AddButton( 240, 77, 2093, 2093, 2, GumpButtonType.Reply, 0 );

			AddImage( 140, 138, 2091 );
			AddImage( 140, 335, 2091 );


			AddPage( 1 );

			AddImage( 128, 152, 2086 );

			AddHtmlLocalized( 147, 150, 160, 18, 1049593, 200, false, false ); // Attributes

			AddHtmlLocalized( 153, 168, 160, 18, 1049578, 16000229, false, false ); // Hits
			AddHtml( 280, 168, 75, 18, String.Format( "<div align=right>{0}/{1}</div>", c.Hits, c.HitsMax ), false, false );

			AddHtmlLocalized( 153, 186, 160, 18, 1049579, 16000229, false, false ); // Stamina
			AddHtml( 280, 186, 75, 18, String.Format( "<div align=right>{0}/{1}</div>", c.Stam, c.StamMax ), false, false );

			AddHtmlLocalized( 153, 204, 160, 18, 1049580, 16000229, false, false ); // Mana
			AddHtml( 280, 204, 75, 18, String.Format( "<div align=right>{0}/{1}</div>", c.Mana, c.ManaMax ), false, false );

			AddHtmlLocalized( 153, 222, 160, 18, 1028335, 16000229, false, false ); // Strength
			AddHtml( 320, 222, 35, 18, String.Format( "<div align=right>{0}</div>", c.Str ), false, false );

			AddHtmlLocalized( 153, 240, 160, 18, 3000113, 16000229, false, false ); // Dexterity
			AddHtml( 320, 240, 35, 18, String.Format( "<div align=right>{0}</div>", c.Dex ), false, false );

			AddHtmlLocalized( 153, 258, 160, 18, 3000112, 16000229, false, false ); // Intelligence
			AddHtml( 320, 258, 35, 18, String.Format( "<div align=right>{0}</div>", c.Int ), false, false );

			AddImage( 128, 278, 2086 );

			AddHtmlLocalized( 147, 276, 160, 18, 3001016, 200, false, false ); // Miscellaneous

			AddHtmlLocalized( 153, 294, 160, 18, 1049581, 16000229, false, false ); // Armor Rating
			AddHtml( 320, 294, 35, 18, String.Format( "<div align=right>{0}</div>", c.VirtualArmor ), false, false );

			AddButton( 340, 358, 5601, 5605, 0, GumpButtonType.Page, 2 );
			AddButton( 317, 358, 5603, 5607, 0, GumpButtonType.Page, 3 );


			AddPage( 2 );

			AddImage( 128, 152, 2086 );

			AddHtmlLocalized( 147, 150, 160, 18, 3001030, 200, false, false ); // Combat Ratings

			AddHtmlLocalized( 153, 168, 160, 18, 1044103, 16000229, false, false ); // Wrestling
			AddHtml( 320, 168, 35, 18, FormatSkill( c, SkillName.Wrestling ), false, false );

			AddHtmlLocalized( 153, 186, 160, 18, 1044087, 16000229, false, false ); // Tactics
			AddHtml( 320, 186, 35, 18, FormatSkill( c, SkillName.Tactics ), false, false );

			AddHtmlLocalized( 153, 204, 160, 18, 1044086, 16000229, false, false ); // Magic Resistance
			AddHtml( 320, 204, 35, 18, FormatSkill( c, SkillName.MagicResist ), false, false );

			AddHtmlLocalized( 153, 222, 160, 18, 1044061, 16000229, false, false ); // Anatomy
			AddHtml( 320, 222, 35, 18, FormatSkill( c, SkillName.Anatomy ), false, false );

			AddHtmlLocalized( 153, 240, 160, 18, 1044090, 16000229, false, false ); // Poisoning
			AddHtml( 320, 240, 35, 18, FormatSkill( c, SkillName.Poisoning ), false, false );

			AddImage( 128, 260, 2086 );

			AddHtmlLocalized( 147, 258, 160, 18, 3001032, 200, false, false ); // Lore & Knowledge

			AddHtmlLocalized( 153, 276, 160, 18, 1044085, 16000229, false, false ); // Magery
			AddHtml( 320, 276, 35, 18, FormatSkill( c, SkillName.Magery ), false, false );

			AddHtmlLocalized( 153, 294, 160, 18, 1044076, 16000229, false, false ); // Evaluating Intelligence
			AddHtml( 320, 294, 35, 18,FormatSkill( c, SkillName.EvalInt ), false, false );

			AddHtmlLocalized( 153, 312, 160, 18, 1044106, 16000229, false, false ); // Meditation
			AddHtml( 320, 312, 35, 18, FormatSkill( c, SkillName.Meditation ), false, false );

			AddButton( 340, 358, 5601, 5605, 0, GumpButtonType.Page, 3 );
			AddButton( 317, 358, 5603, 5607, 0, GumpButtonType.Page, 1 );

			AddPage( 3 );

			AddImage( 128, 152, 2086 );

			AddHtmlLocalized( 147, 150, 160, 18, 1049563, 200, false, false ); // Preferred Foods
			AddHtmlLocalized( 153, 168, 160, 18, 1049565, 16000229, false, false ); // Fruits and Vegetables

			AddImage( 128, 188, 2086 );

			AddHtmlLocalized( 147, 186, 160, 18, 1049569, 200, false, false ); // Pack Instincts
			AddHtmlLocalized( 153, 204, 160, 18, 3000340, 16000229, false, false ); // None

			AddImage( 128, 224, 2086 );

			AddHtmlLocalized( 147, 222, 160, 18, 1049594, 200, false, false ); // Loyalty Rating
			AddHtmlLocalized( 153, 240, 160, 18, (!c.Controled || c.Loyalty == PetLoyalty.None) ? 1061643 : 1049594 + (int)c.Loyalty, 16000229, false, false );

			AddButton( 340, 358, 5601, 5605, 0, GumpButtonType.Page, 1 );
			AddButton( 317, 358, 5603, 5607, 0, GumpButtonType.Page, 2 );
		}
	}
}